summaryrefslogtreecommitdiffstats
path: root/src/shrpx_worker_process.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-13 08:53:16 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-13 08:53:16 +0000
commitfef16cb88298ba07a9841a5a98e5afaa48bcb6d6 (patch)
tree4c895c4ad1fdad31773ded63e5a1effb74185315 /src/shrpx_worker_process.h
parentReleasing progress-linux version 1.60.0-1~progress7.99u1. (diff)
downloadnghttp2-fef16cb88298ba07a9841a5a98e5afaa48bcb6d6.tar.xz
nghttp2-fef16cb88298ba07a9841a5a98e5afaa48bcb6d6.zip
Merging upstream version 1.61.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'src/shrpx_worker_process.h')
-rw-r--r--src/shrpx_worker_process.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/shrpx_worker_process.h b/src/shrpx_worker_process.h
index f432503..155b565 100644
--- a/src/shrpx_worker_process.h
+++ b/src/shrpx_worker_process.h
@@ -49,8 +49,8 @@ struct WorkerProcessConfig {
// IPv6 socket, or -1 if not used
int server_fd6;
#ifdef ENABLE_HTTP3
- // CID prefixes for the new worker process.
- std::vector<std::array<uint8_t, SHRPX_QUIC_CID_PREFIXLEN>> cid_prefixes;
+ // Worker IDs for the new worker process.
+ std::vector<WorkerID> worker_ids;
// IPC socket to read forwarded QUIC UDP datagram from the current
// worker process.
int quic_ipc_fd;